@@ -373,7 +373,7 @@ int slhaBasicReader( int mode, int (*getLnPar)(int, char*), int *anydate,char *
 /* NORMAL BLOCK */      
       { blockStr*newBlock;
         if( sscanf(buff+6,"%*s %s", rest)==EOF) scale=-1;  
-        else if(sscanf(buff+6,"%*s %*s %lf %s", &scale, rest)!=1)
+        else if(sscanf(buff+6,"%*s %*[^=]= %lf %s", &scale, rest)!=1)
         { 
            sprintf(wTxt,"SLHAreader: line %d: Unexpected BLOCK specification",nLine);
            addWarning(wTxt);
