@@ -1,3 +1,3 @@
 
 #include"dynamic_cs.h"
-int VVdecay=1;
\ No newline at end of file
+int VWdecay=1,VZdecay=1;
