@@ -70,7 +70,7 @@ int  getNumCoeff(lVert*vv, double * coeff);
 typedef struct{ double width; txtList pdList[2]; int status;}  decayTableStr;
 
 extern double   (*sqme)(int nsub,double GG,REAL *pvect,REAL*cb_coeff, int * err_code);
-extern double   decayPcm(double am0,  double  am1,  double  am2);
+extern REAL   decayPcm(REAL am0,  REAL  am1,  REAL  am2);
 extern double   decayPcmW(double m0,double m1,double m2,double w1,double w2,int N);
 extern int      ForceUG;
 extern int      procInfo1(numout*cc, int *nsub, int * nin, int *nout);
@@ -82,6 +82,7 @@ extern          decayTableStr* decayTable;
 extern void     cleanDecayTable(void);
 extern int      pname2lib(char*pname, char * libname);
 extern double   decay2Info(char * pname, FILE* f);
+extern int      useSLHAwidth;
 extern double   pWidth(char *name, txtList * LL);
 extern double   pWidthCC(numout*cc,int*err);
 extern double   aWidth(char *name);
