@@ -59,6 +59,10 @@ static REAL sqrMom(int nin, char * momnum, REAL * lv)
 }
 
 
+#ifdef forMICROMEGAS
+double DDmomSQ=0;
+#endif
+
 int prepDen(int nden, int nin,double BWrange2, REAL*dmass,REAL*dwidth, char** Qtxt,REAL*momenta,
      REAL*Q0,COMPLEX*Q1,REAL*Q2)
 { static int ndenmem=0;
@@ -90,31 +94,32 @@ int prepDen(int nden, int nin,double BWrange2, REAL*dmass,REAL*dwidth, char** Qt
      int k;
      for(k=1;k<4;k++){ mq2 -=momenta[k]*momenta[k]; 
                        mne2-=momenta[k+4]*momenta[k+4];}
-     Q1[i]=(*loopFF__)(sgn,sqrt(fabs(mq2)),dmass[i],sqrt(fabs(mne2)));
+     Q1[i]=(*loopFF__)(sgn,Sqrt(Fabs(mq2)),dmass[i],Sqrt(Fabs(mne2)));
      Q2[i]=Q1[i]*Q1[i];
      Q0[i]=1;
      continue;
    } 
-   if(WIDTH_FOR_OMEGA && !stype(nin,Qtxt[i])) dwidth[i]=0.01*fabs(dmass[i]);
+   if(WIDTH_FOR_OMEGA && !stype(nin,Qtxt[i])) dwidth[i]=0.01*Fabs(dmass[i]);
 #endif
 
-  double s=sqrMom(nin,Qtxt[i],momenta);
-  Q1[i]=dmass[i]*dmass[i]-s;
-  if(dwidth[i]>0 && dmass[i]>0 &&  s>0 )
-  {  
-     REAL w=sqrt(s)*dwidth[i], q2=Q1[i]*Q1[i];
-     w=sqrt(s)*dwidth[i];
-     
-     if(q2>(BWrange2+1)*w*w)  w=0; else if(q2> BWrange2*w*w) w=((BWrange2+1)*w*w-q2)/w; 
+  Q1[i]=dmass[i]*dmass[i]-sqrMom(nin,Qtxt[i],momenta);
+#ifdef forMICROMEGAS  
+  if(strcmp(Qtxt[i],"\1\3")==0) Q1[i]+=DDmomSQ;   
+#endif  
+  if(dwidth[i])
+  {  REAL w,w2, q2=Q1[i]*Q1[i];
+     w=dmass[i]*dwidth[i];
+     w2=w*w;
+     if(q2>BWrange2*w2) { if(q2<(BWrange2+1)*w2) q2=(BWrange2+1) *w2; w2=0; }
 
-     Q2[i]=1/(q2+w*w);
+     Q2[i]=1/(q2+w2);
      Q0[i]=Q2[i]*Q1[i]*Q1[i];
-     Q1[i]=1/(Q1[i] + I*w);
+     Q1[i]=1/(Q1[i] + I*Sqrt(w2));
   } else
-  {  if(cabs(Q1[i]) < 100*s0max) err=2;
-//     if(cabs(Q1[i]) < 100*s0max)   printf("i=%d s0max=%E cabs(Q1[i]=%E  eps=%E E=%E\n",i, (double)s0max,(double)cabs(Q1[i]),(double)computer_eps,
+  {  if(Cabs(Q1[i]) < 100*s0max) err=2;
+//     if(Cabs(Q1[i]) < 100*s0max)   printf("i=%d s0max=%E Cabs(Q1[i]=%E  eps=%E E=%E\n",i, (double)s0max,(double)Cabs(Q1[i]),(double)computer_eps,
 //     (double)(momenta[0]+momenta[4]));
-//     if(cabs(Q1[i]) < 1000*s0max*computer_eps){ err=2; } 
+//     if(Cabs(Q1[i]) < 1000*s0max*computer_eps){ err=2; } 
      if(!Q1[i]) Q1[i]=s0max;
      Q1[i]=1/Q1[i];
      Q2[i]=Q1[i]*Q1[i];
