@@ -10,6 +10,6 @@ extern  denom_struct   denom[2 * maxvert - 2];
 
 extern int  denrno;
 
-extern void  saveanaliticresult(poly rnum, poly factn, poly factd, vcsect vcs, int nFile);
+extern void  saveanaliticresult(poly rnum, poly factn, poly factd, vcsect vcs, int ndiag, int nFile);
 
 #endif
