@@ -18,6 +18,7 @@
 #include "pvars.h"
 #include "getmem.h"
 #include "read_func.h"
+#include "reader_c.h"
 
 #define minvarmem  ((unsigned)sizeof(struct varrec)  + 1 - STRSIZ)
 #define minlagrmem ((unsigned)sizeof(struct algvert) + 1 - STRSIZ)
@@ -51,6 +52,7 @@ static void errorMessage( char * fieldName, char * format, ...)
    vsprintf(dump,format,args);
    va_end(args);
 
+printf("dump=|%s|\n",dump);
    if (strcmp(dump,"*") == 0)
     sprintf(errorText,"Error in table '%s' line %d field '%s'\nposition %u: %s",
 	  tabName,nLine,fieldName,rderrpos,errmesstxt(rderrcode) );
@@ -162,25 +164,14 @@ static int ExtFunc,aWidth,aWidth1, depQ;
 
 static int setPub=0;
 
-
+   
 static void*  act_33(char* ch,int n, void**args)
 {  int i,MathFunc=0;
-   char _ch_[100];
-   char math[]=" + - * / ^ if"
-   " sqrt pow  exp log log10 sin cos tan asin acos atan sinh cosh tanh asinh acosh atanh atan2"  
-   " conj cimag creal carg cabs"
-   " cacos casin catan ccos csin ctan cacosh casinh catanh ccosh csinh ctanh" 
-   " cexp clog clog10 cpow csqrt conj cproj ";
 
-   if(ch[0]=='.') rderrcode=typemismatch;
-   
-   sprintf(_ch_," %s ",ch);
-    
-   if(strstr(math,_ch_)) MathFunc=1; 
-  
+   if(ch[0]=='.') {rderrcode=typemismatch; return NULL;}
+   MathFunc= isCMathF(ch);
    if(MathFunc) for(i=0;i<n;i++) if(args[i]==&String) {rderrcode=typemismatch; return NULL;}
-     
-   if(!MathFunc) { if(!strcmp(ch,"aWidth")) aWidth=1; else  ExtFunc=1;}     
+   if(!MathFunc) { if(!strcmp(ch,"aWidth")) aWidth=1; else ExtFunc=1;}     
    return &Number;
 }
 
@@ -474,7 +465,7 @@ static void  clearLatexNames(void)
 }
 
 static int isPrtclName(char*p){ return strlen(p)<P_NAME_SIZE-2 
- && !strchr(p,' ')&& !strchr(p,')') && !strchr(p,')') && !strchr(p,'%');  }
+ && !strchr(p,' ')&& !strchr(p,'(') && !strchr(p,')') && !strchr(p,'%');  }
 
 static int q3SM(int N)
 {
@@ -538,7 +529,7 @@ static int  readparticles(int  check, int ugForce )
          for ( i=0;i<=1;i++)
          {
             if (check && (! isPrtclName(pName[i])))
-            {  errorMessage(fldName[i],"incorrect particle name '%s'",pName[i]);
+            {  errorMessage(fldName[i],"incorrect particle name '%s'.\n It can't be longer than %d or contain (/)/percent symbols",pName[i],P_NAME_SIZE-3);
                return 0;
             }
 
@@ -572,7 +563,7 @@ static int  readparticles(int  check, int ugForce )
 
       prtclbase[nparticles-1].spin=itmp;
       
-      if( 1!=sscanf(numtxt,"%ld",&prtclbase[nparticles-1].N)) prtclbase[nparticles-1].N=0;
+      if( 1!=sscanf(numtxt,"%d",&prtclbase[nparticles-1].N)) prtclbase[nparticles-1].N=0;
       
       if(strcmp(p1,p2)==0) prtclbase[nparticles-1].q3=0; else prtclbase[nparticles-1].q3=q3SM(prtclbase[nparticles-1].N);
 
@@ -1477,6 +1468,8 @@ int makeVandP(int rd ,char*path,int L, int mode,char*CalcHEP)
 
   fprintf(f,"int nModelVars=%d;\n",nVar);
   fprintf(f,"int nModelFunc=%d;\n",nFunc);
+  fprintf(f,"static int nCurrentVars=%d;\n",nVar-1);
+  fprintf(f,"int*currentVarPtr=&nCurrentVars;\n");
   fprintf(f,"static char*varNames_[%d]={\n ", nVar+nFunc);
  
   for(first=1,i10=0, i=nv0;i<nmodelvar;i++) if( (i<=nCommonVars|| modelvars[i].pub==1) &&   vararr[i].used) 
@@ -1523,8 +1516,9 @@ int makeVandP(int rd ,char*path,int L, int mode,char*CalcHEP)
   for(i=1;i<=nmodelvar;i++) if( (i<=nCommonVars|| modelvars[i].pub==1) &&   vararr[i].used)
   {
      if (vararr[i].used &&  modelvars[i].func)
-     { checkNaN=0;
-if(i==depQ1) fprintf(f," FirstQ:\n cErr=1;\n");     
+     {  checkNaN=0;
+if(i==depQ1) fprintf(f," FirstQ:\n cErr=1;\n");
+        fprintf(f,"   nCurrentVars=%d;\n", vararr[i].num);
         {  char * ss=(char *)readExpression(modelvars[i].func,rd_c,act_c,free);
            fprintf(f,"   %s=%s;\n",vararr[i].alias,ss+3);
            free(ss);
@@ -1541,6 +1535,7 @@ if(i==depQ1) fprintf(f," FirstQ:\n cErr=1;\n");
   fprintf(f,"   }\n");
   fprintf(f,"   for(i=0;i<nModelVars;i++) VV[i]=V[i];\n");
   fprintf(f,"   cErr=0;\n");
+  fprintf(f,"   nCurrentVars++;\n");
   fprintf(f,"   return 0;\n}\n");
 
 
