@@ -23,8 +23,8 @@ extern int cDiagonalH(int Dim,...);
 extern int cDiagonalA(int Dim,...);
 extern int cDiagonalS(int Dim,...);
 
-extern double complex cMixMatrix(int id,int i,int j);
-extern double complex cMixMatrixU(int id,int i,int j);
+extern COMPLEX cMixMatrix(int id,int i,int j);
+extern COMPLEX cMixMatrixU(int id,int i,int j);
 
 extern int System(char * format, ...);
 extern int openAppend(char * fileName);
@@ -47,7 +47,7 @@ extern double initQCD5(double,double,double,double);
 extern double MbEff(double);
 extern double MtEff(double);
 extern double McEff(double);
-extern double MqEff(double,double);
+extern double MqEff(double mass2GeV, double Q);
 extern double alphaQCD(double);
 extern double nfQCD(double Q);
 extern double poleQmass(double M_M_, double alpha, int nf);
@@ -63,18 +63,19 @@ extern double complex Hgam1V(double z);
 extern double complex Hgam1A(double z);
 extern double Mbp(void);
 
-extern double dbl(REAL a);
-extern double slhaVal0(char *block, double scale);                              
-extern double slhaVal1(char *block, double scale,int i1);                       
-extern double slhaVal2(char *block, double scale,int i1,int i2);                
-extern double slhaVal3(char *block, double scale,int i1,int i2,int i3);         
-extern double slhaVal4(char *block, double scale,int i1,int i2,int i3,int i4);  
 
-extern int  slhaValExists0(char *block);                                      
-extern int  slhaValExists1(char *block,int i1);                               
-extern int  slhaValExists2(char *block,int i1,int i2);                        
-extern int  slhaValExists3(char *block,int i1,int i2,int i3);                 
-extern int  slhaValExists4(char *block,int i1,int i2,int i3,int i4);          
+extern double dbl(REAL a);
+extern double slhaVal0(char *block, double scale);
+extern double slhaVal1(char *block, double scale,int i1);
+extern double slhaVal2(char *block, double scale,int i1,int i2);
+extern double slhaVal3(char *block, double scale,int i1,int i2,int i3);
+extern double slhaVal4(char *block, double scale,int i1,int i2,int i3,int i4);
+
+extern int  slhaValExists0(char *block);
+extern int  slhaValExists1(char *block,int i1);
+extern int  slhaValExists2(char *block,int i1,int i2);
+extern int  slhaValExists3(char *block,int i1,int i2,int i3);
+extern int  slhaValExists4(char *block,int i1,int i2,int i3,int i4);
 
 
 
@@ -91,7 +92,6 @@ extern double complex lGG5higgs(double Q,char*hName);
 
 /* To avoid avto-prototyping  
 
-extern double  dbl(double);
 extern double  sqrt(double);
 extern double  sin(double);
 extern double  cos(double);
